@@ -7,6 +7,9 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
+
+from test.integration.helpers import authorize
 
 from . import get_b2_auth_data
 from .bucket_cleaner import BucketCleaner
@@ -14,4 +17,5 @@ from .test_raw_api import cleanup_old_buckets
 
 if __name__ == '__main__':
     cleanup_old_buckets()
-    BucketCleaner(False, *get_b2_auth_data()).cleanup_buckets()
+    BucketCleaner(dont_cleanup_old_buckets=False,
+                  b2_api=authorize(get_b2_auth_data())[0]).cleanup_buckets()
