@@ -7,34 +7,34 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
-from abc import ABCMeta, abstractmethod
 import json
-import unittest.mock as mock
 import os
 import platform
 import shutil
 import stat
+import sys
 import tempfile
+import unittest.mock as mock
+from abc import ABCMeta, abstractmethod
 
 import pytest
-
 from apiver_deps import (
     ALL_CAPABILITIES,
-    AbstractAccountInfo,
-    InMemoryAccountInfo,
-    UploadUrlPool,
-    SqliteAccountInfo,
-    TempDir,
     B2_ACCOUNT_INFO_ENV_VAR,
     XDG_CONFIG_HOME_ENV_VAR,
+    AbstractAccountInfo,
+    InMemoryAccountInfo,
+    SqliteAccountInfo,
+    UploadUrlPool,
 )
 from apiver_deps_exception import CorruptAccountInfo, MissingAccountData
 
-from .fixtures import *
+from .fixtures import *  # noqa: F401, F403
 
 
-class WindowsSafeTempDir(TempDir):
+class WindowsSafeTempDir(tempfile.TemporaryDirectory):
     def __exit__(self, exc_type, exc_val, exc_tb):
         try:
             super().__exit__(exc_type, exc_val, exc_tb)
@@ -238,9 +238,11 @@ class AccountInfoBase(metaclass=ABCMeta):
             ).get_bucket_id_or_none_from_bucket_name('my-bucket')
             assert 'my-bucket' == self._make_info(
             ).get_bucket_name_or_none_from_bucket_id('bucket-0')
+        assert ('my-bucket', 'bucket-0') in account_info.list_bucket_names_ids()
         account_info.remove_bucket_name('my-bucket')
         assert account_info.get_bucket_id_or_none_from_bucket_name('my-bucket') is None
         assert account_info.get_bucket_name_or_none_from_bucket_id('bucket-0') is None
+        assert ('my-bucket', 'bucket-0') not in account_info.list_bucket_names_ids()
         if self.PERSISTENCE:
             assert self._make_info().get_bucket_id_or_none_from_bucket_name('my-bucket') is None
             assert self._make_info().get_bucket_name_or_none_from_bucket_id('bucket-0') is None
@@ -335,7 +337,7 @@ class TestSqliteAccountInfo(AccountInfoBase):
     @pytest.fixture(autouse=True)
     def setUp(self, request):
         self.db_path = tempfile.NamedTemporaryFile(
-            prefix='tmp_b2_tests_%s__' % (request.node.name,), delete=True
+            prefix=f'tmp_b2_tests_{request.node.name}__', delete=True
         ).name
         try:
             os.unlink(self.db_path)
@@ -344,6 +346,7 @@ class TestSqliteAccountInfo(AccountInfoBase):
         self.test_home = tempfile.mkdtemp()
 
         yield
+
         for cleanup_method in [
             lambda: os.unlink(self.db_path), lambda: shutil.rmtree(self.test_home)
         ]:
@@ -360,7 +363,7 @@ class TestSqliteAccountInfo(AccountInfoBase):
         """
         Test that a new database won't be readable by just any user
         """
-        s = SqliteAccountInfo(file_name=self.db_path,)
+        SqliteAccountInfo(file_name=self.db_path,)
         mode = os.stat(self.db_path).st_mode
         assert stat.filemode(mode) == '-rw-------'
 
@@ -413,30 +416,26 @@ class TestSqliteAccountInfo(AccountInfoBase):
                 last_upgrade_to_run=last_upgrade_to_run,
             )
 
-    def test_uses_default(self):
-        account_info = self._make_sqlite_account_info(
-            env={
+    def test_uses_xdg_config_home(self, apiver):
+        is_xdg_os = bool(SqliteAccountInfo._get_xdg_config_path())
+        with WindowsSafeTempDir() as d:
+            env = {
                 'HOME': self.test_home,
                 'USERPROFILE': self.test_home,
             }
-        )
-        actual_path = os.path.abspath(account_info.filename)
-        assert os.path.join(self.test_home, '.b2_account_info') == actual_path
 
-    def test_uses_xdg_config_home(self, apiver):
-        with WindowsSafeTempDir() as d:
-            account_info = self._make_sqlite_account_info(
-                env={
-                    'HOME': self.test_home,
-                    'USERPROFILE': self.test_home,
-                    XDG_CONFIG_HOME_ENV_VAR: d,
-                }
-            )
+            if is_xdg_os:
+                # pass the env. variable on XDG-like OS only
+                env[XDG_CONFIG_HOME_ENV_VAR] = d
+
+            account_info = self._make_sqlite_account_info(env=env)
             if apiver in ['v0', 'v1']:
                 expected_path = os.path.abspath(os.path.join(self.test_home, '.b2_account_info'))
-            else:
+            elif is_xdg_os:
                 assert os.path.exists(os.path.join(d, 'b2'))
                 expected_path = os.path.abspath(os.path.join(d, 'b2', 'account_info'))
+            else:
+                expected_path = os.path.abspath(os.path.join(self.test_home, '.b2_account_info'))
             actual_path = os.path.abspath(account_info.filename)
             assert expected_path == actual_path
 
@@ -468,3 +467,14 @@ class TestSqliteAccountInfo(AccountInfoBase):
             expected_path = os.path.abspath(os.path.join(d, 'b2_account_info'))
             actual_path = os.path.abspath(account_info.filename)
             assert expected_path == actual_path
+
+    def test_resolve_xdg_os_default(self):
+        is_xdg_os = bool(SqliteAccountInfo._get_xdg_config_path())
+        assert is_xdg_os == (sys.platform not in ('win32', 'darwin'))
+
+    def test_resolve_xdg_os_default_no_env_var(self, monkeypatch):
+        # ensure that XDG_CONFIG_HOME_ENV_VAR doesn't to resolve XDG-like OS
+        monkeypatch.delenv(XDG_CONFIG_HOME_ENV_VAR, raising=False)
+
+        is_xdg_os = bool(SqliteAccountInfo._get_xdg_config_path())
+        assert is_xdg_os == (sys.platform not in ('win32', 'darwin'))
