@@ -7,31 +7,36 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
 import time
-
-import pytest
 from contextlib import suppress
 from unittest import mock
-from ..test_base import create_key
 
 import apiver_deps
-from apiver_deps import B2Api
-from apiver_deps import B2HttpApiConfig
-from apiver_deps import B2Http
-from apiver_deps import DummyCache
-from apiver_deps import EncryptionAlgorithm
-from apiver_deps import EncryptionMode
-from apiver_deps import EncryptionSetting
-from apiver_deps import FileIdAndName
-from apiver_deps import FileRetentionSetting
-from apiver_deps import InMemoryAccountInfo
-from apiver_deps import LegalHold
-from apiver_deps import RawSimulator
-from apiver_deps import RetentionMode
-from apiver_deps import NO_RETENTION_FILE_SETTING
-from apiver_deps import ApplicationKey, FullApplicationKey
-from apiver_deps_exception import RestrictedBucket, InvalidArgument
+import pytest
+from apiver_deps import (
+    NO_RETENTION_FILE_SETTING,
+    ApplicationKey,
+    B2Api,
+    B2Http,
+    B2HttpApiConfig,
+    EncryptionAlgorithm,
+    EncryptionKey,
+    EncryptionMode,
+    EncryptionSetting,
+    FileIdAndName,
+    FileRetentionSetting,
+    FullApplicationKey,
+    InMemoryAccountInfo,
+    InMemoryCache,
+    LegalHold,
+    RawSimulator,
+    RetentionMode,
+)
+from apiver_deps_exception import AccessDenied, FileNotPresent, InvalidArgument, RestrictedBucket
+
+from ..test_base import create_key
 
 if apiver_deps.V <= 1:
     from apiver_deps import FileVersionInfo as VFileVersion
@@ -43,17 +48,42 @@ class TestApi:
     @pytest.fixture(autouse=True)
     def setUp(self):
         self.account_info = InMemoryAccountInfo()
-        self.cache = DummyCache()
+        self.cache = InMemoryCache()
         self.api = B2Api(
             self.account_info, self.cache, api_config=B2HttpApiConfig(_raw_api_class=RawSimulator)
         )
         self.raw_api = self.api.session.raw_api
         (self.application_key_id, self.master_key) = self.raw_api.create_account()
 
+    @pytest.mark.apiver(from_ver=3)
+    def test_authorize_signature_v3_default_realm(self):
+        self.api.authorize_account(
+            self.application_key_id,
+            self.master_key,
+        )
+
+    @pytest.mark.apiver(from_ver=3)
+    def test_authorize_signature_v3_explicit_realm(self):
+        self.api.authorize_account(
+            self.application_key_id,
+            self.master_key,
+            'production',
+        )
+
+    @pytest.mark.apiver(to_ver=2)
+    def test_authorize_signature_up_to_ver_2(self):
+        self.api.authorize_account(
+            'production',
+            self.application_key_id,
+            self.master_key,
+        )
+
     def test_get_file_info(self):
         self._authorize_account()
         bucket = self.api.create_bucket('bucket1', 'allPrivate')
-        created_file = bucket.upload_bytes(b'hello world', 'file')
+        created_file = bucket.upload_bytes(
+            b'hello world', 'file', cache_control="private, max-age=3600"
+        )
 
         result = self.api.get_file_info(created_file.id_)
 
@@ -69,7 +99,9 @@ class TestApi:
                 'contentSha1': '2aae6c35c94fcfb415dbe95f408b9ce91ee846ed',
                 'contentType': 'b2/x-auto',
                 'fileId': '9999',
-                'fileInfo': {},
+                'fileInfo': {
+                    'b2-cache-control': 'private, max-age=3600',
+                },
                 'fileName': 'file',
                 'fileRetention': {
                     'isClientAuthorizedToRead': True,
@@ -84,12 +116,116 @@ class TestApi:
                 'serverSideEncryption': {
                     'mode': 'none'
                 },
-                'uploadTimestamp': 5000
+                'uploadTimestamp': 5000,
             }
         else:
             assert isinstance(result, VFileVersion)
             assert result == created_file
 
+    def test_get_file_info_by_name(self):
+        self._authorize_account()
+        bucket = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket.upload_bytes(
+            b'hello world',
+            'file',
+        )
+        result = self.api.get_file_info_by_name('bucket1', 'file')
+
+        expected_result = {
+            'fileId': '9999',
+            'fileName': 'file',
+            'fileInfo': {},
+            'serverSideEncryption': {
+                'mode': 'none'
+            },
+            'legalHold': None,
+            'fileRetention': {
+                'mode': None,
+                'retainUntilTimestamp': None
+            },
+            'size': 11,
+            'uploadTimestamp': 5000,
+            'contentType': 'b2/x-auto',
+            'contentSha1': '2aae6c35c94fcfb415dbe95f408b9ce91ee846ed',
+            'replicationStatus': None,
+        }
+
+        if apiver_deps.V <= 1:
+            expected_result.update({
+                'accountId': None,
+                'action': 'upload',
+                'bucketId': None,
+            })
+
+        assert result.as_dict() == expected_result
+
+    def test_get_hidden_file_info_by_name(self):
+        self._authorize_account()
+        bucket = self.api.create_bucket('bucket1', 'allPrivate')
+        bucket.upload_bytes(
+            b'hello world',
+            'hidden-file.txt',
+        )
+        bucket.hide_file('hidden-file.txt')
+        result = self.api.get_file_info_by_name('bucket1', 'hidden-file.txt')
+
+        expected_result = {
+            'fileId': '9998',
+            'fileName': 'hidden-file.txt',
+            'fileInfo': {},
+            'serverSideEncryption': {
+                'mode': 'none'
+            },
+            'legalHold': None,
+            'fileRetention': {
+                'mode': None,
+                'retainUntilTimestamp': None
+            },
+            'size': 0,
+            'uploadTimestamp': 5001,
+            'contentSha1': 'none',
+            'replicationStatus': None,
+        }
+
+        if apiver_deps.V <= 1:
+            expected_result.update({
+                'accountId': None,
+                'action': 'upload',
+                'bucketId': None,
+            })
+
+        assert result.as_dict() == expected_result
+
+    def test_get_non_existent_file_info_by_name(self):
+        self._authorize_account()
+        _ = self.api.create_bucket('bucket1', 'allPrivate')
+        with pytest.raises(FileNotPresent):
+            _ = self.api.get_file_info_by_name('bucket1', 'file-does-not-exist.txt')
+
+    def test_get_file_info_by_name_with_properties(self):
+        encr_setting = EncryptionSetting(
+            EncryptionMode.SSE_C, EncryptionAlgorithm.AES256, EncryptionKey(b'secret', None)
+        )
+        lh_setting = LegalHold.ON
+        retention_setting = FileRetentionSetting(RetentionMode.COMPLIANCE, 100)
+
+        self._authorize_account()
+        bucket = self.api.create_bucket('bucket1', 'allPrivate', is_file_lock_enabled=True)
+        _ = bucket.upload_bytes(
+            b'hello world',
+            'file',
+            encryption=encr_setting,
+            legal_hold=lh_setting,
+            file_retention=retention_setting
+        )
+
+        result = self.api.get_file_info_by_name('bucket1', 'file')
+
+        assert encr_setting.mode == result.server_side_encryption.mode
+        assert encr_setting.algorithm == result.server_side_encryption.algorithm
+        assert lh_setting == result.legal_hold
+        assert retention_setting == result.file_retention
+
     @pytest.mark.parametrize(
         'expected_delete_bucket_output',
         [
@@ -147,6 +283,23 @@ class TestApi:
         self.api.create_bucket('bucket2', 'allPrivate')
         assert [b.name for b in self.api.list_buckets(bucket_name='bucket1')] == ['bucket1']
 
+    @pytest.mark.apiver(from_ver=3)
+    def test_list_buckets_from_cache(self):
+        bucket = type("bucket", (), {"name": "bucket", "id_": "ID-0"})
+        self._authorize_account()
+        self.cache.set_bucket_name_cache([bucket])
+
+        def list_buckets(*args, **kwargs):
+            buckets = self.api.list_buckets(*args, **kwargs)
+            return [(b.name, b.id_) for b in buckets]
+
+        assert list_buckets(use_cache=True) == [('bucket', 'ID-0')]
+        assert list_buckets(bucket_name="bucket", use_cache=True) == [('bucket', 'ID-0')]
+        assert list_buckets(bucket_name="bucket2", use_cache=True) == []
+        assert list_buckets(bucket_id="ID-0", use_cache=True) == [('bucket', 'ID-0')]
+        assert list_buckets(bucket_id="ID-2", use_cache=True) == []
+        assert self.api.list_buckets() == []
+
     def test_buckets_with_encryption(self):
         self._authorize_account()
         sse_b2_aes = EncryptionSetting(
@@ -182,7 +335,11 @@ class TestApi:
 
         # now check it with no readBucketEncryption permission to see that it's unknown
         key = create_key(self.api, ['listBuckets'], 'key1')
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         buckets = {
             b.name: b
             for b in self.api.list_buckets()  # scan again with new key
@@ -222,7 +379,11 @@ class TestApi:
         key = create_key(self.api, ['listBuckets'], 'key1')
 
         # authorize with the key
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
 
         # expire the auth token we just got
         self.raw_api.expire_auth_token(self.account_info.get_account_auth_token())
@@ -235,14 +396,22 @@ class TestApi:
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         self.api.create_bucket('bucket2', 'allPrivate')
         key = create_key(self.api, ['listBuckets'], 'key1', bucket_id=bucket1.id_)
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         assert [b.name for b in self.api.list_buckets(bucket_name=bucket1.name)] == ['bucket1']
 
     def test_get_bucket_by_name_with_bucket_restriction(self):
         self._authorize_account()
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         key = create_key(self.api, ['listBuckets'], 'key1', bucket_id=bucket1.id_)
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         assert self.api.get_bucket_by_name('bucket1').id_ == bucket1.id_
 
     def test_list_buckets_with_restriction_and_wrong_name(self):
@@ -250,7 +419,11 @@ class TestApi:
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         bucket2 = self.api.create_bucket('bucket2', 'allPrivate')
         key = create_key(self.api, ['listBuckets'], 'key1', bucket_id=bucket1.id_)
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         with pytest.raises(RestrictedBucket) as excinfo:
             self.api.list_buckets(bucket_name=bucket2.name)
         assert str(excinfo.value) == 'Application key is restricted to bucket: bucket1'
@@ -260,7 +433,11 @@ class TestApi:
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         self.api.create_bucket('bucket2', 'allPrivate')
         key = create_key(self.api, ['listBuckets'], 'key1', bucket_id=bucket1.id_)
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         with pytest.raises(RestrictedBucket) as excinfo:
             self.api.list_buckets()
         assert str(excinfo.value) == 'Application key is restricted to bucket: bucket1'
@@ -270,13 +447,21 @@ class TestApi:
         bucket1 = self.api.create_bucket('bucket1', 'allPrivate')
         self.api.create_bucket('bucket2', 'allPrivate')
         key = create_key(self.api, ['listBuckets'], 'key1', bucket_id=bucket1.id_)
-        self.api.authorize_account('production', key.id_, key.application_key)
+        self.api.authorize_account(
+            application_key_id=key.id_,
+            application_key=key.application_key,
+            realm='production',
+        )
         with pytest.raises(RestrictedBucket) as excinfo:
             self.api.list_buckets(bucket_id='not the one bound to the key')
-        assert str(excinfo.value) == 'Application key is restricted to bucket: %s' % (bucket1.id_,)
+        assert str(excinfo.value) == f'Application key is restricted to bucket: {bucket1.id_}'
 
     def _authorize_account(self):
-        self.api.authorize_account('production', self.application_key_id, self.master_key)
+        self.api.authorize_account(
+            application_key_id=self.application_key_id,
+            application_key=self.master_key,
+            realm='production',
+        )
 
     def test_update_file_retention(self):
         self._authorize_account()
@@ -423,18 +608,18 @@ class TestApi:
     def test_list_keys_v1(self):
         self._authorize_account()
         for i in range(20):
-            self.api.create_key(['readFiles'], 'testkey%s' % (i,))
+            self.api.create_key(['readFiles'], f'testkey{i}')
         with mock.patch.object(self.api, 'DEFAULT_LIST_KEY_COUNT', 10):
             response = self.api.list_keys()
         assert response['nextApplicationKeyId'] == 'appKeyId18'
         assert response['keys'] == [
             {
                 'accountId': 'account-0',
-                'applicationKeyId': 'appKeyId%s' % (ind,),
+                'applicationKeyId': f'appKeyId{ind}',
                 'bucketId': None,
                 'capabilities': ['readFiles'],
                 'expirationTimestamp': None,
-                'keyName': 'testkey%s' % (ind,),
+                'keyName': f'testkey{ind}',
                 'namePrefix': None,
             } for ind in [
                 0,
@@ -454,7 +639,7 @@ class TestApi:
     def test_list_keys_v2(self):
         self._authorize_account()
         for i in range(20):
-            self.api.create_key(['readFiles'], 'testkey%s' % (i,))
+            self.api.create_key(['readFiles'], f'testkey{i}')
         with mock.patch.object(self.api, 'DEFAULT_LIST_KEY_COUNT', 10):
             keys = list(self.api.list_keys())
         assert [key.id_ for key in keys] == [
@@ -480,3 +665,39 @@ class TestApi:
             'appKeyId9',
         ]
         assert isinstance(keys[0], ApplicationKey)
+
+    def test_get_key(self):
+        self._authorize_account()
+        key = self.api.create_key(['readFiles'], 'testkey')
+
+        if apiver_deps.V <= 1:
+            key_id = key['applicationKeyId']
+        else:
+            key_id = key.id_
+
+        assert self.api.get_key(key_id) is not None
+
+        if apiver_deps.V <= 1:
+            self.api.delete_key(key_id)
+        else:
+            self.api.delete_key(key)
+
+        assert self.api.get_key(key_id) is None
+        assert self.api.get_key('non-existent') is None
+
+    def test_delete_file_version_bypass_governance(self):
+        self._authorize_account()
+        bucket = self.api.create_bucket('bucket1', 'allPrivate')
+        created_file = bucket.upload_bytes(
+            b'hello world',
+            'file',
+            file_retention=FileRetentionSetting(RetentionMode.GOVERNANCE,
+                                                int(time.time()) + 100),
+        )
+
+        with pytest.raises(AccessDenied):
+            self.api.delete_file_version(created_file.id_, 'file')
+
+        self.api.delete_file_version(created_file.id_, 'file', bypass_governance=True)
+        with pytest.raises(FileNotPresent):
+            bucket.get_file_info_by_name(created_file.file_name)
