@@ -7,16 +7,50 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
-from io import BytesIO
 import os
 import platform
+import tempfile
 import unittest.mock as mock
+from io import BytesIO
 
 import pytest
 
 from ..test_base import TestBase
-
+from .deps import (
+    NO_RETENTION_FILE_SETTING,
+    SSE_B2_AES,
+    SSE_NONE,
+    AbstractProgressListener,
+    B2Api,
+    BucketSimulator,
+    CopySource,
+    DownloadDestBytes,
+    EncryptionAlgorithm,
+    EncryptionKey,
+    EncryptionMode,
+    EncryptionSetting,
+    EncryptionSettingFactory,
+    FakeResponse,
+    FileRetentionSetting,
+    FileSimulator,
+    FileVersionInfo,
+    LargeFileUploadState,
+    LegalHold,
+    MetadataDirectiveMode,
+    ParallelDownloader,
+    Part,
+    PreSeekedDownloadDest,
+    RawSimulator,
+    RetentionMode,
+    SimpleDownloader,
+    StubAccountInfo,
+    UploadSourceBytes,
+    UploadSourceLocalFile,
+    WriteIntent,
+    hex_sha1_of_bytes,
+)
 from .deps_exception import (
     AlreadyFailed,
     B2Error,
@@ -25,25 +59,9 @@ from .deps_exception import (
     InvalidRange,
     InvalidUploadSource,
     MaxRetriesExceeded,
-    UnsatisfiableRange,
     SSECKeyError,
+    UnsatisfiableRange,
 )
-from .deps import B2Api
-from .deps import LargeFileUploadState
-from .deps import DownloadDestBytes, PreSeekedDownloadDest
-from .deps import FileVersionInfo
-from .deps import LegalHold, FileRetentionSetting, RetentionMode, NO_RETENTION_FILE_SETTING
-from .deps import MetadataDirectiveMode
-from .deps import Part
-from .deps import AbstractProgressListener
-from .deps import StubAccountInfo, RawSimulator, BucketSimulator, FakeResponse, FileSimulator
-from .deps import ParallelDownloader
-from .deps import SimpleDownloader
-from .deps import UploadSourceBytes
-from .deps import hex_sha1_of_bytes, TempDir
-from .deps import EncryptionAlgorithm, EncryptionSetting, EncryptionSettingFactory, EncryptionMode, \
-    EncryptionKey, SSE_NONE, SSE_B2_AES
-from .deps import CopySource, UploadSourceLocalFile, WriteIntent
 
 SSE_C_AES = EncryptionSetting(
     mode=EncryptionMode.SSE_C,
@@ -109,9 +127,7 @@ class StubProgressListener(AbstractProgressListener):
         valid, _ = self.is_valid_reason(**kwargs)
         return valid
 
-    def is_valid_reason(
-        self, check_closed=True, check_progress=True, check_monotonic_progress=False
-    ):
+    def is_valid_reason(self, check_progress=True, check_monotonic_progress=False):
         progress_end = -1
         if self.history[progress_end] == 'closed':
             progress_end = -2
@@ -126,8 +142,6 @@ class StubProgressListener(AbstractProgressListener):
                 prev = val
         if self.total != self.last_byte_count:
             return False, 'total different than last_byte_count'
-        if check_closed and self.history[-1] != 'closed':
-            return False, 'no "closed" at the end of history'
         if check_progress and len(self.history[1:progress_end]) < 2:
             return False, 'progress in history has less than 2 entries'
         return True, ''
@@ -142,7 +156,7 @@ class CanRetry(B2Error):
     """
 
     def __init__(self, can_retry):
-        super(CanRetry, self).__init__(None, None, None, None, None)
+        super().__init__(None, None, None, None, None)
         self.can_retry = can_retry
 
     def should_retry_upload(self):
@@ -283,7 +297,8 @@ class TestGetFileInfo(TestCaseWithBucket):
 
         self.assertIsInstance(info, FileVersionInfo)
         expected = (
-            a_id, 'a', 11, 'upload', 'b2/x-auto', 'none', NO_RETENTION_FILE_SETTING, LegalHold.UNSET
+            a_id, 'a', 11, 'upload', 'b2/x-auto', 'none', NO_RETENTION_FILE_SETTING,
+            LegalHold.UNSET, None
         )
         actual = (
             info.id_,
@@ -294,6 +309,7 @@ class TestGetFileInfo(TestCaseWithBucket):
             info.server_side_encryption.mode.value,
             info.file_retention,
             info.legal_hold,
+            info.cache_control,
         )
         self.assertEqual(expected, actual)
 
@@ -742,7 +758,7 @@ class TestUpload(TestCaseWithBucket):
         self.assertEqual(SSE_C_AES_NO_SECRET, file_info.server_side_encryption)
 
     def test_upload_local_file_sse_b2(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             data = b'hello world'
             write_file(path, data)
@@ -752,7 +768,7 @@ class TestUpload(TestCaseWithBucket):
             self._check_file_contents('file1', data)
 
     def test_upload_local_file_sse_c(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             data = b'hello world'
             write_file(path, data)
@@ -762,7 +778,7 @@ class TestUpload(TestCaseWithBucket):
             self._check_file_contents('file1', data)
 
     def test_upload_local_file_retention(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             data = b'hello world'
             write_file(path, data)
@@ -784,8 +800,23 @@ class TestUpload(TestCaseWithBucket):
         self.bucket.upload_bytes(data, 'file1', progress_listener=progress_listener)
         self.assertTrue(progress_listener.is_valid())
 
+    def test_upload_local_file_cache_control(self):
+        with tempfile.TemporaryDirectory() as d:
+            path = os.path.join(d, 'file1')
+            data = b'hello world'
+            write_file(path, data)
+            cache_control = 'max-age=3600'
+            file_info = self.bucket.upload_local_file(path, 'file1', cache_control=cache_control)
+            self.assertEqual(cache_control, file_info.cache_control)
+
+    def test_upload_bytes_cache_control(self):
+        data = b'hello world'
+        cache_control = 'max-age=3600'
+        file_info = self.bucket.upload_bytes(data, 'file1', cache_control=cache_control)
+        self.assertEqual(cache_control, file_info.cache_control)
+
     def test_upload_local_file(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             data = b'hello world'
             write_file(path, data)
@@ -794,7 +825,7 @@ class TestUpload(TestCaseWithBucket):
 
     @pytest.mark.skipif(platform.system() == 'Windows', reason='no os.mkfifo() on Windows')
     def test_upload_fifo(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             os.mkfifo(path)
             with self.assertRaises(InvalidUploadSource):
@@ -802,7 +833,7 @@ class TestUpload(TestCaseWithBucket):
 
     @pytest.mark.skipif(platform.system() == 'Windows', reason='no os.symlink() on Windows')
     def test_upload_dead_symlink(self):
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file1')
             os.symlink('non-existing', path)
             with self.assertRaises(InvalidUploadSource):
@@ -895,7 +926,7 @@ class TestUpload(TestCaseWithBucket):
         self._upload_part(large_file_id, 1, data[:part_size])
         progress_listener = StubProgressListener()
         file_info = self.bucket.upload_bytes(
-            data, 'file1', progress_listener=progress_listener, file_infos={'property': 'value1'}
+            data, 'file1', progress_listener=progress_listener, file_info={'property': 'value1'}
         )
         self.assertEqual(large_file_id, file_info.id_)
         self._check_file_contents('file1', data)
@@ -908,7 +939,7 @@ class TestUpload(TestCaseWithBucket):
         self._upload_part(large_file_id, 1, data[:part_size])
         progress_listener = StubProgressListener()
         file_info = self.bucket.upload_bytes(
-            data, 'file1', progress_listener=progress_listener, file_infos={'property': 'value2'}
+            data, 'file1', progress_listener=progress_listener, file_info={'property': 'value2'}
         )
         self.assertNotEqual(large_file_id, file_info.id_)
         self._check_file_contents('file1', data)
@@ -948,7 +979,7 @@ class TestConcatenate(TestCaseWithBucket):
 
         f1_id = self.bucket.upload_bytes(data, 'f1').id_
         f2_id = self.bucket.upload_bytes(data, 'f1').id_
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file')
             write_file(path, data)
             created_file = self._create_remote(
@@ -971,7 +1002,7 @@ class TestConcatenate(TestCaseWithBucket):
         for data in [b'hello_world', self._make_data(self.simulator.MIN_PART_SIZE * 3)]:
             f1_id = self.bucket.upload_bytes(data, 'f1', encryption=SSE_C_AES).id_
             f2_id = self.bucket.upload_bytes(data, 'f1', encryption=SSE_C_AES_2).id_
-            with TempDir() as d:
+            with tempfile.TemporaryDirectory() as d:
                 path = os.path.join(d, 'file')
                 write_file(path, data)
                 created_file = self._create_remote(
@@ -980,7 +1011,7 @@ class TestConcatenate(TestCaseWithBucket):
                         UploadSourceLocalFile(path),
                         CopySource(f2_id, length=len(data), offset=0, encryption=SSE_C_AES_2),
                     ],
-                    file_name='created_file_%s' % (len(data),),
+                    file_name=f'created_file_{len(data)}',
                     encryption=SSE_C_AES
                 )
             self.assertIsInstance(created_file, FileVersionInfo)
@@ -990,7 +1021,7 @@ class TestConcatenate(TestCaseWithBucket):
             )
             expected = (
                 mock.ANY,
-                'created_file_%s' % (len(data),),
+                f'created_file_{len(data)}',
                 mock.ANY,  # FIXME: this should be equal to len(data) * 3,
                 # but there is a problem in the simulator/test code somewhere
                 SSE_C_AES_NO_SECRET
@@ -1028,7 +1059,7 @@ class DownloadTests:
     DATA = 'abcdefghijklmnopqrs'
 
     def setUp(self):
-        super(DownloadTests, self).setUp()
+        super().setUp()
         self.file_info = self.bucket.upload_bytes(self.DATA.encode(), 'file1')
         self.encrypted_file_info = self.bucket.upload_bytes(
             self.DATA.encode(), 'enc_file1', encryption=SSE_C_AES
@@ -1040,7 +1071,6 @@ class DownloadTests:
         assert self.download_dest.get_bytes_written() == expected_result.encode()
         if check_progress_listener:
             valid, reason = self.progress_listener.is_valid_reason(
-                check_closed=False,
                 check_progress=False,
                 check_monotonic_progress=True,
             )
@@ -1101,7 +1131,7 @@ class DownloadTests:
         #
         # 123defghij1234567890
 
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file2')
             download_dest = PreSeekedDownloadDest(seek_target=3, local_file_path=path)
             data = b'12345678901234567890'
@@ -1132,7 +1162,7 @@ class DownloadTests:
         #
         # 1234567defghij567890
 
-        with TempDir() as d:
+        with tempfile.TemporaryDirectory() as d:
             path = os.path.join(d, 'file2')
             download_dest = PreSeekedDownloadDest(seek_target=7, local_file_path=path)
             data = b'12345678901234567890'
@@ -1184,14 +1214,14 @@ class TestDownloadDefault(DownloadTests, EmptyFileDownloadScenarioMixin, TestCas
 
 class TestDownloadSimple(DownloadTests, EmptyFileDownloadScenarioMixin, TestCaseWithBucket):
     def setUp(self):
-        super(TestDownloadSimple, self).setUp()
+        super().setUp()
         download_manager = self.bucket.api.services.download_manager
         download_manager.strategies = [SimpleDownloader(force_chunk_size=20)]
 
 
 class TestDownloadParallel(DownloadTests, TestCaseWithBucket):
     def setUp(self):
-        super(TestDownloadParallel, self).setUp()
+        super().setUp()
         download_manager = self.bucket.api.services.download_manager
         download_manager.strategies = [
             ParallelDownloader(
@@ -1212,7 +1242,7 @@ class TruncatedFakeResponse(FakeResponse):
     """
 
     def __init__(self, *args, **kwargs):
-        super(TruncatedFakeResponse, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.data_bytes = self.data_bytes[:4]
 
 
@@ -1233,14 +1263,14 @@ class TestCaseWithTruncatedDownloadBucket(TestCaseWithBucket):
 
 class TestTruncatedDownloadSimple(DownloadTests, TestCaseWithTruncatedDownloadBucket):
     def setUp(self):
-        super(TestTruncatedDownloadSimple, self).setUp()
+        super().setUp()
         download_manager = self.bucket.api.services.download_manager
         download_manager.strategies = [SimpleDownloader(force_chunk_size=20)]
 
 
 class TestTruncatedDownloadParallel(DownloadTests, TestCaseWithTruncatedDownloadBucket):
     def setUp(self):
-        super(TestTruncatedDownloadParallel, self).setUp()
+        super().setUp()
         download_manager = self.bucket.api.services.download_manager
         download_manager.strategies = [
             ParallelDownloader(
