@@ -7,11 +7,11 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
 import warnings
 
 from ..test_base import TestBase
-
 from .deps import rename_argument, rename_function
 
 
@@ -48,8 +48,7 @@ class TestRenameArgument(TestBase):
         with self.assertRaises(
             AssertionError,
             msg=
-            "rename_argument decorator is still used in version %s when old argument name 'aaa' was scheduled to be dropped in 0.1.2. It is time to remove the mapping."
-            % (self.VERSION,),
+            f"rename_argument decorator is still used in version {self.VERSION} when old argument name 'aaa' was scheduled to be dropped in 0.1.2. It is time to remove the mapping.",
         ):
 
             @rename_argument('aaa', 'bbb', '0.1.0', '0.1.2', current_version=self.VERSION)
