@@ -7,30 +7,45 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
 import concurrent.futures as futures
 import os
 import platform
 import sys
+import tempfile
 import threading
 import time
 import unittest
-from unittest.mock import MagicMock, ANY
+from unittest.mock import ANY, MagicMock
 
 import pytest
 
 from ..test_base import TestBase
-
-from .deps import B2Folder, LocalFolder
-from .deps import BoundedQueueExecutor, zip_folders
-from .deps import LocalSyncPath, B2SyncPath
-from .deps import FileVersionInfo
-from .deps import KeepOrDeleteMode, NewerFileSyncMode, CompareVersionMode
-from .deps import ScanPoliciesManager, DEFAULT_SCAN_MANAGER
-from .deps import Synchronizer
-from .deps import TempDir
-from .deps import parse_sync_folder
-from .deps_exception import UnSyncableFilename, NotADirectory, UnableToCreateDirectory, EmptyDirectory, InvalidArgument, CommandError
+from .deps import (
+    DEFAULT_SCAN_MANAGER,
+    B2Folder,
+    B2SyncPath,
+    BoundedQueueExecutor,
+    CompareVersionMode,
+    FileVersionInfo,
+    KeepOrDeleteMode,
+    LocalFolder,
+    LocalSyncPath,
+    NewerFileSyncMode,
+    ScanPoliciesManager,
+    Synchronizer,
+    parse_sync_folder,
+    zip_folders,
+)
+from .deps_exception import (
+    CommandError,
+    EmptyDirectory,
+    InvalidArgument,
+    NotADirectory,
+    UnableToCreateDirectory,
+    UnSyncableFilename,
+)
 
 DAY = 86400000  # milliseconds
 TODAY = DAY * 100  # an arbitrary reference time for testing
@@ -71,7 +86,7 @@ class TestFolder(TestSync):
     MOD_TIMES = {'.dot_file': TODAY - DAY, 'hello.': TODAY - DAY}
 
     def setUp(self):
-        super(TestFolder, self).setUp()
+        super().setUp()
 
         self.root_dir = ''
 
@@ -261,9 +276,9 @@ class TestLocalFolder(TestFolder):
     __test__ = True
 
     def setUp(self):
-        super(TestLocalFolder, self).setUp()
+        super().setUp()
 
-        self.temp_dir = TempDir()
+        self.temp_dir = tempfile.TemporaryDirectory()
         self.root_dir = self.temp_dir.__enter__()
 
     def tearDown(self):
@@ -397,7 +412,7 @@ class TestB2Folder(TestFolder):
     }
 
     def setUp(self):
-        super(TestB2Folder, self).setUp()
+        super().setUp()
         self.bucket = MagicMock()
         self.bucket.ls.return_value = []
         self.api = MagicMock()
@@ -665,7 +680,7 @@ class TestParseSyncFolder(TestBase):
     def test_local(self):
         if platform.system() == 'Windows':
             drive, _ = os.path.splitdrive(os.getcwd())
-            expected = 'LocalFolder(\\\\?\\%s\\foo)' % (drive,)
+            expected = f'LocalFolder(\\\\?\\{drive}\\foo)'
         else:
             expected = 'LocalFolder(/foo)'
         self._check_one(expected, '/foo')
@@ -673,7 +688,7 @@ class TestParseSyncFolder(TestBase):
     def test_local_trailing_slash(self):
         if platform.system() == 'Windows':
             drive, _ = os.path.splitdrive(os.getcwd())
-            expected = 'LocalFolder(\\\\?\\%s\\foo)' % (drive,)
+            expected = f'LocalFolder(\\\\?\\{drive}\\foo)'
         else:
             expected = 'LocalFolder(/foo)'
         self._check_one(expected, '/foo/')
@@ -696,7 +711,7 @@ class TestFolderExceptions:
         ],
     )
     def test_ensure_present_not_a_dir(self, exception, msg):
-        with TempDir() as path:
+        with tempfile.TemporaryDirectory() as path:
             file = os.path.join(path, 'clearly_a_file')
             with open(file, 'w') as f:
                 f.write(' ')
@@ -714,7 +729,7 @@ class TestFolderExceptions:
         ],
     )
     def test_ensure_present_unable_to_create(self, exception, msg):
-        with TempDir() as path:
+        with tempfile.TemporaryDirectory() as path:
             file = os.path.join(path, 'clearly_a_file')
             with open(file, 'w') as f:
                 f.write(' ')
@@ -734,7 +749,7 @@ class TestFolderExceptions:
         ],
     )
     def test_ensure_non_empty(self, exception, msg):
-        with TempDir() as path:
+        with tempfile.TemporaryDirectory() as path:
             folder = parse_sync_folder(path, MagicMock())
             with pytest.raises(exception, match=msg):
                 folder.ensure_non_empty()
