@@ -7,10 +7,16 @@
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+from __future__ import annotations
 
 from ..test_base import TestBase
-
-from .deps import b2_url_encode, b2_url_decode, choose_part_ranges, format_and_scale_number, format_and_scale_fraction
+from .deps import (
+    b2_url_decode,
+    b2_url_encode,
+    choose_part_ranges,
+    format_and_scale_fraction,
+    format_and_scale_number,
+)
 
 # These are from the B2 Docs (https://www.backblaze.com/b2/docs/string_encoding.html)
 ENCODING_TEST_CASES = [
@@ -212,17 +218,17 @@ ENCODING_TEST_CASES = [
     {
         'fullyEncoded': '%7F',
         'minimallyEncoded': '%7F',
-        'string': u'\u007f'
+        'string': '\u007f'
     },
     {
         'fullyEncoded': '%E8%87%AA%E7%94%B1',
         'minimallyEncoded': '%E8%87%AA%E7%94%B1',
-        'string': u'\u81ea\u7531'
+        'string': '\u81ea\u7531'
     },
     {
         'fullyEncoded': '%F0%90%90%80',
         'minimallyEncoded': '%F0%90%90%80',
-        'string': u'\U00010400'
+        'string': '\U00010400'
     },
 ]
 
@@ -237,10 +243,7 @@ class TestUrlEncoding(TestBase):
 
             expected_encoded = (minimally_encoded, fully_encoded)
             if encoded not in expected_encoded:
-                print(
-                    'string: %s   encoded: %s   expected: %s' %
-                    (repr(string), encoded, expected_encoded)
-                )
+                print(f'string: {repr(string)}   encoded: {encoded}   expected: {expected_encoded}')
             self.assertTrue(encoded in expected_encoded)
             self.assertEqual(string, b2_url_decode(fully_encoded))
             self.assertEqual(string, b2_url_decode(minimally_encoded))
